pub struct AssetsOptions {
pub tailwind_binary_path: PathBuf,
pub assets_dir: PathBuf,
pub hashing_strategy: AssetHashingStrategy,
}Fields
tailwind_binary_path: PathBufPath to the TailwindCSS CLI binary. By default tailwindcss, which assumes you’ve installed it globally (for example, through Homebrew) and that it is in your PATH.
This is commonly set to ./node_modules/.bin/tailwindcss or similar, in order to use a locally installed version.
assets_dir: PathBufDirectory inside the output directory to place built assets in.
Defaults to _maudit.
Note that this value is not automatically joined with the output_dir in BuildOptions. Use BuildOptions::route_assets_options() to get a RouteAssetsOptions with the correct final path.
hashing_strategy: AssetHashingStrategyStrategy to use when hashing assets for fingerprinting.
Defaults to AssetHashingStrategy::Precise in production builds, and AssetHashingStrategy::FastImprecise in development builds. Note that this means that the cache isn’t shared between dev and prod builds by default, if you have a lot of assets you may want to set this to the same value in both environments.