pub struct PrefetchOptions {
pub strategy: PrefetchStrategy,
pub prerender: bool,
pub eagerness: PrerenderEagerness,
}Fields
strategy: PrefetchStrategyThe prefetch strategy to use
prerender: boolEnable prerendering using Speculation Rules API if supported.
eagerness: PrerenderEagernessHint to the browser as to how eagerly it should prefetch/prerender. Only works when prerender is enabled and browser supports Speculation Rules API.